Module recipe

Module recipe 

SubMsRecipe impl. Behind the harness feature.

Structs

SpscRingBufferRecipe
Stages: enqueue, dequeue. Each measured on the thread that owns the respective end; sample arrays merged back into the harness on the producer thread after the consumer joins.